@@ -7,7 +7,7 @@ NULL
 #' @aliases append_rownames,data.frame-method
 setMethod(
   f = "append_rownames",
-  signature = signature(x = "data.frame"),
+  signature = c(x = "data.frame"),
   definition = function(x, after = 0, remove = TRUE, var = "rownames") {
     ## Validation
     assert_length(after, 1)
