@@ -1,5 +1,16 @@
 # PREDICATES
 
+# Not exported =================================================================
+is_unique <- function(x, na.rm = FALSE) {
+  if (na.rm) x <- stats::na.omit(x)
+  length(unique(x)) <= 1
+}
+is_empty_string <- function(x, na.rm = FALSE) {
+  assert_type(x, "character")
+  if (na.rm) x <- stats::na.omit(x)
+  x == ""
+}
+
 # Helpers ======================================================================
 #' Utility Predicates
 #'
